@@ -142,11 +142,11 @@ $messages = array(
 
 * [http://www.mediawiki.org/wiki/Manual:Configuration_settings لیسته‌ی هه‌ڵبژاردنه‌كان و ڕێكخستنه‌كان]
 * [http://www.mediawiki.org/wiki/Manual:FAQ MediaWiki FAQ]
-* [http://lists.wikimedia.org/mailman/listinfo/mediawiki-announce لیستی وه‌شانه‌كانی ویكیمیدیا]',
+* [https://lists.wikimedia.org/mailman/listinfo/mediawiki-announce لیستی وه‌شانه‌كانی ویكیمیدیا]',
 
 'about'          => 'سه‌باره‌ت',
 'article'        => 'بابه‌ت',
-'newwindow'      => '(له‌ په‌ڕه‌یه‌كی نوێدا بیكه‌ره‌وه‌)',
+'newwindow'      => '(لە پەڕەیەکی نوێ دەکرێتەوە)',
 'cancel'         => 'ھەڵوەشاندن',
 'qbfind'         => 'دۆزه‌ر',
 'qbbrowse'       => 'بگه‌ڕێ',
@@ -167,9 +167,9 @@ $messages = array(
 'errorpagetitle'    => 'هه‌ڵه‌',
 'returnto'          => 'بگه‌ڕێوه‌ بۆ $1.',
 'tagline'           => 'له‌ {{SITENAME}}',
-'help'              => 'یارمەتی',
-'search'            => 'گه‌ڕان',
-'searchbutton'      => 'گه‌ڕان',
+'help'              => 'ڕێنمایی',
+'search'            => 'گەڕان',
+'searchbutton'      => 'بگەڕە',
 'go'                => 'ده‌ی',
 'searcharticle'     => 'بڕۆ',
 'history'           => 'مێژووی په‌ڕه‌',
@@ -200,7 +200,7 @@ $messages = array(
 'articlepage'       => 'ناوه‌ڕۆكی بابه‌ت ببینه‌',
 'talk'              => 'قسەوباس',
 'views'             => 'بینین',
-'toolbox'           => 'تووڵی كه‌ره‌سه‌كان',
+'toolbox'           => 'ئامرازدان',
 'userpage'          => 'په‌ڕه‌ی به‌كارهێنه‌ر نیشانبده‌',
 'projectpage'       => 'په‌ڕه‌ی پرۆژه‌ نیشانبده‌',
 'imagepage'         => 'په‌ڕه‌ی وێنه‌ نیشانبده‌',
@@ -216,15 +216,21 @@ $messages = array(
 'viewcount'         => 'ئه‌م په‌ڕه‌یه‌ ده‌ستكاریی كراوه‌ {{PLURAL:$1|یه‌كجار|$1 جار}}',
 'protectedpage'     => 'په‌ڕه‌یه‌كی پارێزراو',
 'jumpto'            => 'باز بده‌ بۆ:',
-'jumptonavigation'  => 'نمایشكردن',
+'jumptonavigation'  => 'ڕوانگە',
 'jumptosearch'      => 'گه‌ڕان',
 
 # All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
 'aboutsite'            => 'دەربارەی {{SITENAME}}',
 'copyrightpage'        => '{{ns:project}}:مافەکانی لەبەرگرتنەوە',
+'currentevents-url'    => 'Project:ڕووداوە بەردەوامەکان',
+'edithelp'             => 'ڕێنمایی بۆ دەستکاری کردن',
+'edithelppage'         => 'Help:دەستکاری کردن',
 'faq'                  => 'پرسیاری هه‌میشه‌ دووباره‌(پهد(',
 'mainpage'             => 'ده‌ستپێک',
 'mainpage-description' => 'ده‌ستپێک',
+'portal'               => 'دەروازەی بەکارھێنەران',
+'portal-url'           => 'Project: دەروازەی بەکارھێنەران',
+'privacy'              => 'سیاسەتی پاراستنی داتاکان',
 
 'versionrequired'     => 'پێویستیت به‌ وه‌شانی $1 ـی‌ ویكیمیدیایه‌',
 'versionrequiredtext' => 'پێویستیت به‌ وه‌شانی $1 ـێ ویكیمیدیا هه‌یه‌ بۆ به‌كاربردنی ئه‌م په‌ڕه‌یه‌
@@ -239,14 +245,14 @@ $messages = array(
 'editsectionhint'         => 'ده‌ستكاریی به‌شی: $1',
 'toc'                     => 'ناوەڕۆک',
 'showtoc'                 => 'نیشاندان',
-'hidetoc'                 => 'شاردنه‌وه‌',
+'hidetoc'                 => 'شاردنەوە',
 'thisisdeleted'           => '؟$1 نیشانی بده‌ یا بیگه‌ڕێنه‌ره‌وه‌',
 'viewdeleted'             => '$1 نیشان بده‌؟',
 'restorelink'             => '{{PLURAL:$1|ده‌ستكاریی سڕدراوه‌كه‌ بكه‌|$1 ده‌ستكارییان بكه‌}}',
 
 # Short words for each namespace, by default used in the namespace tab in monobook
 'nstab-main'      => 'وتار',
-'nstab-user'      => 'به‌كارهێنه‌ر',
+'nstab-user'      => 'پەڕەی بەکارھێنەر',
 'nstab-media'     => 'میدیا',
 'nstab-special'   => 'تایبه‌ت',
 'nstab-project'   => 'په‌ڕه‌ی پرۆژه‌',
@@ -276,92 +282,190 @@ $messages = array(
 'filenotfound'       => 'په‌ڕگه‌ی "$1" نه‌دۆزرایه‌وه‌',
 'badtitle'           => 'ناونیشانێكی بێ كه‌ڵك',
 'viewsource'         => 'سه‌رچاوه‌ ببینه‌',
-'viewsourcefor'      => 'سه‌رچاوه‌ی $1 ببینه‌',
+'viewsourcefor'      => 'بۆ $1',
 
 # Login and logout pages
-'welcomecreation'    => '== خۆش هاتیت, $1! ==
+'welcomecreation'         => '== خۆش هاتیت, $1! ==
 
 هه‌ژماری تایبه‌تی تۆ سه‌ركه‌وتووانه‌ دروست كرا، له‌بیرت نه‌چێت گۆڕانكاری له {{SITENAME}} تایبه‌ت به‌خۆت دا بكه‌.',
-'loginpagetitle'     => 'ناوی چوونه‌ ژووره‌وه‌',
-'yourname'           => 'ناوی به‌كارهێنه‌وه‌',
-'yourpassword'       => 'تێپه‌ڕه‌وشه‌',
-'yourpasswordagain'  => 'تێپه‌ڕه‌وشه‌ دووباره‌',
-'remembermypassword' => 'زانیاریی چوونه‌ ژووره‌وه‌م له‌سه‌ر ئه‌م كۆمپیوته‌ره‌ پاشه‌كه‌وت بكه‌',
-'yourdomainname'     => 'ناوی دۆمه‌ینی خۆت',
-'userlogin'          => '  / دروست کردنی ھەژمار چوونە ژورەوە',
-'logout'             => 'ده‌رچوون',
-'userlogout'         => 'بڕۆ ده‌ره‌وه‌',
-'notloggedin'        => 'له‌ ژووره‌وه‌ نیت',
-'nologin'            => 'ناتوانیت بچییه‌ ژووره‌وه‌؟ $1.',
-'nologinlink'        => 'ببه‌ به‌ ئه‌ندام',
-'createaccount'      => 'هه‌ژماری نوێ',
-'gotaccount'         => 'خاوه‌نی هه‌ژماری خۆتی؟ $1.',
-'gotaccountlink'     => 'چوونه‌ ژووره‌وه‌',
-'createaccountmail'  => 'به‌ پۆستی ئه‌لیكترۆنی',
-'badretype'          => 'وشه‌ نهێنییه‌كان له‌یه‌ك ناچن',
-'userexists'         => 'ئه‌و ناوه‌ی تۆ داوته‌ پێشتر كه‌سێكی دیكه‌ به‌كاری بردووه‌',
-'youremail'          => 'پۆستی ئه‌لیكترۆنی خۆت*',
-'username'           => 'ناوی به‌كارهێنه‌ر:',
-'uid'                => 'ژماره‌ی خۆت ID:',
-'yourrealname'       => 'ناوی ڕاستی خۆت*',
-'yourlanguage'       => 'زمان',
-'yourvariant'        => 'ڕه‌گه‌ز',
-'yournick'           => 'نازناو',
-'badsig'             => 'ئیمزاكه‌ هه‌ڵه‌یه‌، ته‌ماشای كۆدی HTML بكه‌‌',
-'emailauthenticated' => 'پۆستی ئه‌لیكترۆنی ناسراو: $1.',
-'emailconfirmlink'   => 'پۆستی ئه‌لیكترۆنی خۆت بنووسه‌',
-'accountcreated'     => 'هه‌ژماره‌كه‌ سه‌ركه‌وتووانه‌ دروست كرا',
-'loginlanguagelabel' => 'زمان: $1',
+'loginpagetitle'          => 'ناوی چوونه‌ ژووره‌وه‌',
+'yourname'                => 'ناوی به‌كارهێنه‌وه‌',
+'yourpassword'            => 'تێپه‌ڕه‌وشه‌',
+'yourpasswordagain'       => 'تێپه‌ڕه‌وشه‌ دووباره‌',
+'remembermypassword'      => 'زانیاریی چوونه‌ ژووره‌وه‌م له‌سه‌ر ئه‌م كۆمپیوته‌ره‌ پاشه‌كه‌وت بكه‌',
+'yourdomainname'          => 'ناوی دۆمه‌ینی خۆت',
+'login'                   => 'تێکەوە (login)',
+'nav-login-createaccount' => 'دروست کردنی ھەژمار/چوونە ژورەوە',
+'userlogin'               => 'دروست کردنی ھەژمار/چوونە ژورەوە',
+'logout'                  => 'ده‌رچوون',
+'userlogout'              => 'دەرچوون',
+'notloggedin'             => 'له‌ ژووره‌وه‌ نیت',
+'nologin'                 => 'ناتوانیت بچییه‌ ژووره‌وه‌؟ $1.',
+'nologinlink'             => 'ببه‌ به‌ ئه‌ندام',
+'createaccount'           => 'هه‌ژماری نوێ',
+'gotaccount'              => 'خاوه‌نی هه‌ژماری خۆتی؟ $1.',
+'gotaccountlink'          => 'چوونه‌ ژووره‌وه‌',
+'createaccountmail'       => 'به‌ پۆستی ئه‌لیكترۆنی',
+'badretype'               => 'وشه‌ نهێنییه‌كان له‌یه‌ك ناچن',
+'userexists'              => 'ئه‌و ناوه‌ی تۆ داوته‌ پێشتر كه‌سێكی دیكه‌ به‌كاری بردووه‌',
+'youremail'               => 'پۆستی ئه‌لیكترۆنی خۆت*',
+'username'                => 'ناوی به‌كارهێنه‌ر:',
+'uid'                     => 'ژماره‌ی خۆت ID:',
+'yourrealname'            => 'ناوی ڕاستی خۆت*',
+'yourlanguage'            => 'زمان',
+'yourvariant'             => 'ڕه‌گه‌ز',
+'yournick'                => 'نازناو',
+'badsig'                  => 'ئیمزاكه‌ هه‌ڵه‌یه‌، ته‌ماشای كۆدی HTML بكه‌‌',
+'emailauthenticated'      => 'پۆستی ئه‌لیكترۆنی ناسراو: $1.',
+'emailconfirmlink'        => 'پۆستی ئه‌لیكترۆنی خۆت بنووسه‌',
+'accountcreated'          => 'هه‌ژماره‌كه‌ سه‌ركه‌وتووانه‌ دروست كرا',
+'loginlanguagelabel'      => 'زمان: $1',
 
 # Password reset dialog
 'resetpass_text'   => '<!-- تێپه‌ڕه‌وشه‌ی هه‌ژماره‌كه‌ سفر بكه‌ره‌وه‌ -->',
 'resetpass_header' => 'تێپه‌ڕه‌وشه‌ سفر بكه‌ره‌وه‌',
 
 # Edit page toolbar
-'bold_sample'   => 'ده‌قی ئه‌ستوور',
-'bold_tip'      => 'ده‌قی ئه‌ستوور',
-'italic_sample' => 'ده‌قی خوار (ئیتالی)',
-'italic_tip'    => 'ده‌قی خوار (ئیتالی)',
-'link_tip'      => 'به‌سته‌رێكی ناوخۆیی',
-'extlink_tip'   => 'به‌سته‌ری ده‌ره‌كی ( ده‌ست پێ ده‌كاتhttp:// سه‌ره‌تاكه‌ی به‌ )',
-'sig_tip'       => 'ئیمزاكه‌ت به‌ مۆری ڕێكه‌وته‌وه‌',
-'hr_tip'        => 'هێڵی ئاسۆیی (ده‌گمه‌ن به‌كاری بهێنه‌)',
+'bold_sample'    => 'ده‌قی ئه‌ستوور',
+'bold_tip'       => 'ده‌قی ئه‌ستوور',
+'italic_sample'  => 'دەقی لار',
+'italic_tip'     => 'دەقی لار',
+'link_sample'    => 'نێوی بەستەر',
+'link_tip'       => 'به‌سته‌رێكی ناوخۆیی',
+'extlink_sample' => 'http://www.example.com سەردێڕی بەستەر',
+'extlink_tip'    => 'به‌سته‌ری ده‌ره‌كی ( ده‌ست پێ ده‌كاتhttp:// سه‌ره‌تاكه‌ی به‌ )',
+'headline_tip'   => 'سەردێڕی ئاست ۲',
+'math_sample'    => 'لەگرە فۆرموول بخەسەر',
+'math_tip'       => ' فۆرموولی بیرکاریی (LaTeX)',
+'nowiki_sample'  => 'لەگەرە دەقی نەڕازراو تێ‌بخە',
+'nowiki_tip'     => 'لەبەرچاو نەگرتنی دارشتنەکانی ویکی',
+'image_tip'      => 'وێنەی نێو دەق',
+'media_tip'      => 'لینکی پەڕگە',
+'sig_tip'        => 'ئیمزاكه‌ت به‌ مۆری ڕێكه‌وته‌وه‌',
+'hr_tip'         => 'هێڵی ئاسۆیی (ده‌گمه‌ن به‌كاری بهێنه‌)',
 
 # Edit pages
-'summary'         => 'پوخته‌',
-'subject'         => 'بابه‌ت / سه‌روتار',
-'minoredit'       => 'ئەم گۆڕانکاری‌یە بچووکە',
-'watchthis'       => 'چاودێڕی ئه‌م په‌ڕه‌یه‌ بكه‌',
-'savearticle'     => 'په‌ڕه‌كه‌ پاشه‌كه‌وت بكه‌',
-'preview'         => 'پێشبینین',
-'showpreview'     => 'په‌ڕه‌ی پێشبینین',
-'showlivepreview' => 'پێشبینینی ڕاسته‌وخۆ',
-'showdiff'        => 'گۆڕانكارییه‌كان نیشانبده‌',
+'summary'                => 'پوختە',
+'subject'                => 'بابه‌ت / سه‌روتار',
+'minoredit'              => 'ئەم گۆڕانکاری‌یە بچووکە',
+'watchthis'              => 'چاودێڕی ئه‌م په‌ڕه‌یه‌ بكه‌',
+'savearticle'            => 'په‌ڕه‌كه‌ پاشه‌كه‌وت بكه‌',
+'preview'                => 'پێشبینین',
+'showpreview'            => 'پێشبینینی پەڕە',
+'showlivepreview'        => 'پێشبینینی ڕاسته‌وخۆ',
+'showdiff'               => 'گۆڕانكارییه‌كان نیشانبده‌',
+'newarticletext'         => "بە دوای بەستەری پەڕەیەک کەوتووی کە ھێشتا دروست نەکراوە. <br /> بۆ دروست کردنی پەڕەکە، لە چوارچێوەکەی خوارەوە دەست کە بە تایپ کردن. (بۆ زانیاری زورتر[[یارمەتی|{{MediaWiki:Helppage}}]] ببینە). <br />  ئەگەر بە ھەڵەوە ھاتویتە ئەگرە، لە سەر دوگمەی '''back'''ی وێبگەڕەکەت کلیک کە.",
+'copyrightwarning'       => "تکایە ئاگادار بن کە ھەموو بەشدارییەک بۆ  {{SITENAME}} وا فەرز ئەکرێت کە لە ژێر «$2» بڵاو دەبنەوە(بۆ ئاگاداری زۆرتر $1 سەیر کە). ئەگەر ناتەوێ  نوسراوەکەت بێ‌ڕەحمانە دەستکاری بکرێت و  بە دڵخواز دیسان بڵاو ببێتەوە، لەگرە پێشکەشی مەکە. <br />\\n ھەروەھا بەڵین ئەدەی کە خۆت ئەمەت نووسیوە، یان لە سەرچاوەیەکی بە دەسەڵاتی گشتی ''(public domain)'' یان سەرچاوەیەکی ھاوتا لەبەرت‌گرتوەتەو.
+<strong>«بەرھەمێک کە مافی لەبەرگرتنەوەی پارێزراوە، بێ ئیجازە  بڵاو مەکەرەوە.»</strong>",
+'template-semiprotected' => '(نیوەپارێزراو)',
+
+# History pages
+'revisionasof' => 'وەک بینینەوەی $1',
+'cur'          => 'ئێستا',
+'last'         => 'پێشوو',
+'histlegend'   => 'وەشانەکان بۆ ھەڵسەنگاندن دیاری بکە و ئەم دوگمەی خوارەوە لێبدە. <br />
+ڕێنمایی:
+(ئێستا) = جیاوازی لەگەڵ وەشانی ئێستا،
+(پێشوو) =جیاوازی لەگەڵ وەشانی پێشوو،
+ب = گۆڕانکاریی بچووک',
+'histfirst'    => 'کۆنترین',
+'histlast'     => 'نوێترین',
+
+# Diffs
+'difference'              => '(جیاوازی نێوان پیاچوونەوەکان)',
+'lineno'                  => 'ھێڵی  $1:',
+'compareselectedversions' => 'ھەڵسەنگاندنی وەشانە ھەڵبژاردراوەکان',
+
+# Search results
+'noexactmatch' => "'''ھیچ پەڕەیەک ھەر بەم سەردێڕەوە نیە.''' 
+ئێستە دەتوانی ئەم پەڕە دروست بکەیت",
+'powersearch'  => 'بە ھێز بگەڕە',
 
 # Preferences page
 'mypreferences' => 'ھەڵبژاردەکانی من',
 
+# Recent changes
+'recentchanges'   => 'دوایین گۆڕانکارییەکان',
+'rcnote'          => "لە خوارەوەدا {{PLURAL:$1|'''۱''' گۆڕانکاری |دوایین '''$1''' گۆڕانکارییەکان}} لە دوایین {{PLURAL:$2|ڕۆژ|'''$2''' ڕۆژەوە}} ، تا $5، $4 دەبینن.",
+'diff'            => 'جیاوازی',
+'hist'            => 'مێژوو',
+'hide'            => 'شاردنەوە',
+'show'            => 'نیشان بە',
+'minoreditletter' => 'ور',
+'newpageletter'   => 'ن',
+'boteditletter'   => 'ڕ',
+
+# Recent changes linked
+'recentchangeslinked' => 'گۆڕانکارییە پەیوەندی‌دارەکان',
+
 # Upload
 'upload' => 'وێنەیەک بار بکە',
 
+# Image description page
+'filehist'   => 'مێژووی پەڕگە',
+'imagelinks' => 'بەستەرەکان',
+
 # Random page
 'randompage' => 'پەڕەیەک بە ھەرەمەکی',
 
 # Miscellaneous special pages
-'move' => 'ناوی ئەم پەڕە بگۆڕە',
+'nbytes'   => '$1 {{PLURAL:$1|بایت|بایت}}',
+'newpages' => 'پەڕە نوێکان',
+'move'     => 'ناوی ئەم پەڕە بگۆڕە',
+
+# Special:AllPages
+'allarticles' => 'ھەمووی وتارەکان',
 
 # Special:Categories
 'categories' => 'هاوپۆله‌كان',
 
+# E-mail user
+'emailuser' => 'بۆ ئەم بەکارھێنەرە E-Mail بنێرە',
+
 # Watchlist
 'mywatchlist' => 'لیستی چاودێڕی‌یەکانم',
 'watch'       => 'چاودێڕی بکە',
 
+# Displayed when you click the "watch" button and it is in the process of watching
+'watching' => 'چاودێڕی...',
+
+# Delete/protect/revert
+'rollbacklink' => 'گەڕاندنەوە',
+
+# Namespace form on various pages
+'invert'         => 'ھەڵبژاردەکان پێچەوانە بکە',
+'blanknamespace' => '(سەرەکی)',
+
 # Contributions
 'mycontris' => 'بەشدارییەکانی من',
 
+# What links here
+'whatlinkshere'       => 'بەسراوەکان بە ئێرەوە',
+'whatlinkshere-links' => '← بەستەرەکان',
+
+# Block/unblock
+'blocklink' => 'بەربەستن',
+
+# Thumbnails
+'thumbnail-more' => 'گەورە کردنەوە',
+
 # Tooltip help for the actions
-'tooltip-pt-userpage' => 'په‌ڕه‌ی تایبه‌تی خۆم',
+'tooltip-pt-userpage'             => 'په‌ڕه‌ی تایبه‌تی خۆم',
+'tooltip-ca-nstab-user'           => 'پەڕەی بەکارھێنەر تەماشا بکە',
+'tooltip-compareselectedversions' => 'جیاوازییەکانی دوو وەشانە دیاریکراوەی ئەم پەڕە ببینە.',
+
+# Media information
+'show-big-image' => 'گەورە کردنەوە',
+
+# Metadata
+'metadata-help'   => 'ئەم پەڕگە زانیاری زێدەی ھەیە، کە لەوە دەچێت کامێرا یان ھێماگر (scanner) خستبێتیە سەری. ئەگەر پەڕگەکە لە حاڵەتی سەرەتاییەکەیەوە دەستکاری کرابێ، شایەد بڕێ لە بڕگەکان بە تەواوی زانیارەکانی وێنە گۆڕدراوەکە نیشان نەدەن.',
+'metadata-fields' => 'ئەو کێڵگە EXIFانە لەم پەیامە بە ڕیز کراون، کاتێک خشتەی metadata کۆ کراوەش بێ ھەر نیشان ئەدرێت. کێڵگەکانی تر تا خشتەکە باز نەکرێ، شاراوەن.
+* make
+* model
+* datetimeoriginal
+* exposuretime
+* fnumber
+* focallength', # Do not translate list items
 
 # Separators for various lists, etc.
 'semicolon-separator' => '؛',
